@@ -110,7 +110,7 @@ def limit_length(subject, max_len=2, from_beginning=True):
             return subject[max_len:]
 
 
-def leftPad(subject, max_len=2, pad_char='0', limit_length=False, from_beginning=True):
+def leftPad(subject, max_len=2, pad_char='0', limit_len=False, from_beginning=True):
     '''
         Convert a subject to snake case.
 
@@ -124,7 +124,7 @@ def leftPad(subject, max_len=2, pad_char='0', limit_length=False, from_beginning
         `pad_char` {str}
             The character to pad the subject with
 
-        [`limit_length`=False] {bool}
+        [`limit_len`=False] {bool}
             If True the subject will have excess characters removed from the beginning or end.
 
         [`from_beginning`=True] {bool}
@@ -141,7 +141,7 @@ def leftPad(subject, max_len=2, pad_char='0', limit_length=False, from_beginning
         leftPad("/esls_test/server_source/TEST.scss",15,' ',True,True) // "/esls_test/serv"
         leftPad("/e/TEST.scss",15,' ',True,False) // "   /e/TEST.scss"
     '''
-    if limit_length is True:
+    if limit_len is True:
         subject = limit_length(subject, max_len, from_beginning)
     subject = str(subject)
     slen = len(subject)
